@@ -22,9 +22,9 @@
 #ifndef HEADER_SUBVIEW2
 #define HEADER_SUBVIEW2
 
-#include <gtk--/table.h>
+#include <gtkmm/table.h>
 #include "docexample.h"
-#include <gtk--/combo.h>
+#include <gtkmm/combo.h>
 
 class SubView2 : 
   public Gtk::Table,
